from datetime import datetime


class Log:
    """Attributes:
    source (str): Source project/file of the log.
    level (str): 'info', 'warn' or 'error'.
    message (str): Log detailed message.
    event (str): Event where the log was triggered.
    """

    def __init__(self, source: str, level: str, message: str, event: str):
        self.source = source
        self.timestamp = str(datetime.now())
        self.level = level.lower()
        self.message = message
        self.event = event



import requests
from pymongo import MongoClient
from logze.models.log import Log


class LogRecorder:
    """Attributes:
    mongo_uri (str): MongoDB connection string.
    db_name (str): MongoDB database name.
    logs_collection_name (str): Name of collection to record data.
    teams_webhook (str): Microsoft Teams webhook url to send error logs in a channel.
    """

    def __init__(
        self,
        mongo_uri: str,
        db_name: str,
        logs_collection_name: str,
        teams_webhook=None,
    ):
        self.mongo_uri = mongo_uri
        self.db_name = db_name
        self.logs_collection_name = logs_collection_name
        self.teams_webhook = teams_webhook

    def record_log(self, log: Log):
        """Record the log into MongoDB
        Attributes:
            log (Log): Log object.
        """
        client = MongoClient(self.mongo_uri)
        db = client[self.db_name]
        logs_collection = db[self.logs_collection_name]
        logs_collection.insert_one(log.__dict__)
        client.close()

        if log.level == "error" and self.teams_webhook is not None:
            url = self.teams_webhook
            headers = {"Content-Type": "application/json"}
            payload = {
                "@type": "MessageCard",
                "@context": "http://schema.org/extensions",
                "summary": "Log message",
                "themeColor": "ff0000",
                "title": f"Log: {log.source}",
                "text": str(log.timestamp) + " " + log.message,
            }
            requests.post(url, headers=headers, json=payload, timeout=5)



from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="logze",
    version="0.1.8",
    description="Library in Python to store logs in MongoDB and send notifications of errors to Microsoft Teams",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Jose Henrique Roveda",
    author_email="josehenriqueroveda@usp.br",
    url="https://github.com/josehenriqueroveda/logze",
    packages=find_packages(),
    install_requires=[
        "pymongo",
        "requests",
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
)
